summaryrefslogtreecommitdiff
path: root/include/ruby/impl/intern/struct.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/intern/struct.h')
-rw-r--r--include/ruby/impl/intern/struct.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/ruby/impl/intern/struct.h b/include/ruby/impl/intern/struct.h
index 281292dfed..dce5803719 100644
--- a/include/ruby/impl/intern/struct.h
+++ b/include/ruby/impl/intern/struct.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_INTERN_STRUCT_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_INTERN_STRUCT_H
+#ifndef RBIMPL_INTERN_STRUCT_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_INTERN_STRUCT_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -24,7 +24,7 @@
#include "ruby/impl/intern/vm.h" /* rb_alloc_func_t */
#include "ruby/impl/value.h"
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
/* struct.c */
VALUE rb_struct_new(VALUE, ...);
@@ -42,6 +42,6 @@ VALUE rb_struct_alloc_noinit(VALUE);
VALUE rb_struct_define_without_accessor(const char *, VALUE, rb_alloc_func_t, ...);
VALUE rb_struct_define_without_accessor_under(VALUE outer, const char *class_name, VALUE super, rb_alloc_func_t alloc, ...);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-#endif /* RUBY3_INTERN_STRUCT_H */
+#endif /* RBIMPL_INTERN_STRUCT_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file